@@ -1,5 +1,5 @@
 nma.ab <-
-function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","rank.prob"),model="het_cor",prior.type,a=0.001,b=0.001,c=10,higher.better=FALSE,digits=4,n.adapt=5000,n.iter=100000,n.burnin=floor(n.iter/2),n.chains=3,n.thin=max(1,floor((n.iter-n.burnin)/100000)),conv.diag=FALSE,trace="",dic=FALSE,postdens=FALSE,mcmc.samples=FALSE){
+function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","rank.prob"),model="het_cor",prior.type,a=0.001,b=0.001,c=10,higher.better=FALSE,digits=4,n.adapt=5000,n.iter=100000,n.burnin=floor(n.iter/2),n.chains=3,n.thin=max(1,floor((n.iter-n.burnin)/100000)),conv.diag=FALSE,trace=NULL,dic=FALSE,postdens=FALSE,mcmc.samples=FALSE){
   ## check the input parameters
   options(warn=1)
   if(missing(s.id)) stop("need to specify study id.")
@@ -19,7 +19,11 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   if(!all(total.n>0)) stop("total number must be positive.")
   if(!all(event.n>=0)) stop("event number must be non-negative.")
   if(!all(event.n%%1==0) | !all(total.n%%1==0)) warning("at least one event number or total number is not integer.")
-  if(!is.element(model,c("hom_ind","het_ind","hom_eqcor","het_eqcor","het_cor"))) stop("model should be specified as \"hom_ind\", \"het_ind\", \"hom_eqcor\", \"het_eqcor\", or \"het_cor\".")
+  if(!is.element(model,c("hom_eqcor","het_eqcor","het_cor"))) stop("model should be specified as \"hom_eqcor\", \"het_eqcor\", or \"het_cor\".")
+
+  if(any(is.na(s.id))|any(is.na(t.id))|any(is.na(event.n))|any(is.na(total.n))){
+    stop("NA is not allowed in the input data set;\n  the rows containing NA should be removed.")
+  }
 
   ## make ids continuous
   s.id.o<-s.id
@@ -42,12 +46,6 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   if(missing(prior.type)) prior.type<-ifelse(model=="het_cor","invwishart","unif")
 
   ## jags model
-  if(model=="hom_ind"){
-    modelstring<-model.binary.hom.ind(prior.type,is.element("rank.prob",param))
-  }
-  if(model=="het_ind"){
-    modelstring<-model.binary.het.ind(prior.type,is.element("rank.prob",param))
-  }
   if(model=="hom_eqcor"){
     modelstring<-model.binary.hom.eqcor(prior.type,is.element("rank.prob",param))
   }
@@ -60,16 +58,6 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   }
 
   ## jags data
-  if(model == "hom_ind"| model == "het_ind"){
-    if(prior.type == "unif"){
-      if(is.element("rank.prob",param)) data.jags<-list(s=s.id,t=t.id,r=event.n,totaln=total.n,len=len,nstudy=nstudy,ntrt=ntrt,c=c,higher.better=higher.better)
-      if(!is.element("rank.prob",param)) data.jags<-list(s=s.id,t=t.id,r=event.n,totaln=total.n,len=len,nstudy=nstudy,ntrt=ntrt,c=c)
-    }
-    if(prior.type == "invgamma"){
-      if(is.element("rank.prob",param)) data.jags<-list(s=s.id,t=t.id,r=event.n,totaln=total.n,len=len,nstudy=nstudy,ntrt=ntrt,a=a,b=b,higher.better=higher.better)
-      if(!is.element("rank.prob",param)) data.jags<-list(s=s.id,t=t.id,r=event.n,totaln=total.n,len=len,nstudy=nstudy,ntrt=ntrt,a=a,b=b)
-    }
-  }
   if(model == "hom_eqcor"| model == "het_eqcor"){
     if(prior.type == "unif"){
       if(is.element("rank.prob",param)) data.jags<-list(s=s.id,t=t.id,r=event.n,totaln=total.n,len=len,nstudy=nstudy,ntrt=ntrt,zeros=rep(0,ntrt),c=c,higher.better=higher.better)
@@ -92,30 +80,6 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
     mu.init[i]<-sum(event.n[t.id==t.id[i]])/sum(total.n[t.id==t.id[i]])
   }
   init.jags<-list(NULL)
-  if(model=="hom_ind"){
-    if(prior.type=="unif"){
-      for(ii in 1:n.chains){
-        init.jags[[ii]]<-list(mu=qnorm(mu.init),vi=rep(0,nstudy),sigma=c/2,.RNG.name="base::Wichmann-Hill",.RNG.seed=rng.seeds[ii])
-      }
-    }
-    if(prior.type=="invgamma"){
-      for(ii in 1:n.chains){
-        init.jags[[ii]]<-list(mu=qnorm(mu.init),vi=rep(0,nstudy),inv.sig.sq=a/b,.RNG.name="base::Wichmann-Hill",.RNG.seed=rng.seeds[ii])
-      }
-    }
-  }
-  if(model=="het_ind"){
-    if(prior.type=="unif"){
-      for(ii in 1:n.chains){
-        init.jags[[ii]]<-list(mu=qnorm(mu.init),vi=rep(0,nstudy),sigma=rep(c/2,ntrt),.RNG.name="base::Wichmann-Hill",.RNG.seed=rng.seeds[ii])
-      }
-    }
-    if(prior.type=="invgamma"){
-      for(ii in 1:n.chains){
-        init.jags[[ii]]<-list(mu=qnorm(mu.init),vi=rep(0,nstudy),inv.sig.sq=rep(a/b,ntrt),.RNG.name="base::Wichmann-Hill",.RNG.seed=rng.seeds[ii])
-      }
-    }
-  }
   if(model=="hom_eqcor"){
     if(prior.type=="unif"){
       for(ii in 1:n.chains){
@@ -148,7 +112,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
 
   ## parameters to be monitored in jags
   if(!is.element("AR",param)) param<-c("AR",param)
-  if(trace!=""){
+  if(!is.null(trace)){
     if(!any(is.element(trace, param))) stop("at least one effect size in argument trace is not specified in argument param.")
   }
   monitor<-param[!is.element(param,c("OR","RR","RD","LOR","LRR"))]
@@ -189,7 +153,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   }
 
   ## run jags
-  cat("start running MCMC...\n")
+  cat("Start running MCMC...\n")
   jags.m<-jags.model(file=textConnection(modelstring),data=data.jags,inits=init.jags,n.chains=n.chains,n.adapt=n.adapt)
   update(jags.m,n.iter=n.burnin)
   jags.out<-coda.samples(model=jags.m,variable.names=monitor,n.iter=n.iter,thin=n.thin)
@@ -198,6 +162,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   smry<-signif(smry,digits=digits)
 
   out<-NULL
+  out$model<-"Binomial likelihood with probit link."
   AR.id<-grep("AR",rownames(smry))
   AR.stat<-array(paste(format(round(smry[AR.id,"Mean"],digits=digits),nsmall=digits)," (",format(round(smry[AR.id,"SD"],digits=digits),nsmall=digits),")",sep=""),dim=c(ntrt,1))
   colnames(AR.stat)<-"Mean (SD)"
@@ -302,7 +267,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   }
 
   if(conv.diag){
-    cat("start calculating MCMC convergence diagnostic statistics...\n")
+    cat("Start calculating MCMC convergence diagnostic statistics...\n")
     conv.out<-gelman.diag(jags.out,multivariate=FALSE)
     conv.out<-conv.out$psrf
     if(is.element("rank.prob",param)){
@@ -313,7 +278,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   }
 
   if(dic){
-    cat("start calculating deviance information criterion statistics...\n")
+    cat("Start calculating deviance information criterion statistics...\n")
     dic.out<-dic.samples(model=jags.m,n.iter=n.iter,thin=n.thin)
     dev<-sum(dic.out$deviance)
     pen<-sum(dic.out$penalty)
@@ -328,8 +293,8 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
     out$mcmc.samples<-jags.out
   }
 
-  if(!all(trace=="")){
-    cat("start saving trace plots...\n")
+  if(!is.null(trace)){
+    cat("Start saving trace plots...\n")
   }
 
   if(is.element("AR",trace)){
@@ -381,7 +346,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
           par(mfrow=c(n.chains,1))
           for(j in 1:n.chains){
             temp<-as.vector(jags.out[[j]][,paste("RR[",i,",",k,"]",sep="")])
-            plot(temp,type="l",col="red",ylab="Relative Risk",xlab="Iterations",main=paste("Chain",j))
+            plot(temp,type="l",col="red",ylab="Risk Ratio",xlab="Iterations",main=paste("Chain",j))
           }
           dev.off()
         }
@@ -396,7 +361,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
           par(mfrow=c(n.chains,1))
           for(j in 1:n.chains){
             temp<-as.vector(jags.out[[j]][,paste("LRR[",i,",",k,"]",sep="")])
-            plot(temp,type="l",col="red",ylab="Log Relative Risk",xlab="Iterations",main=paste("Chain",j))
+            plot(temp,type="l",col="red",ylab="Log Risk Ratio",xlab="Iterations",main=paste("Chain",j))
           }
           dev.off()
         }
@@ -420,7 +385,7 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
   }
 
   if(postdens){
-    cat("start saving posterior density plot for absolute risk...\n")
+    cat("Start saving posterior density plot for absolute risk...\n")
     mcmc<-NULL
     dens<-matrix(0,ntrt,3)
     colnames(dens)<-c("ymax","xmin","xmax")
@@ -438,14 +403,15 @@ function(s.id,t.id,event.n,total.n,data,trtname,param=c("AR","LOR","LRR","RD","r
     xmax<-max(dens[,"xmax"])
     cols<-rainbow(ntrt,s=1,v=0.6)
     pdf("AbsoluteRiskDensityPlot.pdf")
-    par(mfrow=c(1,1))
-    plot(density(mcmc[[1]]),xlim=c(xmin,xmax),ylim=c(0,ymax),xlab="Absolute Risk",ylab="Density",main="",col=cols[1],lty=1,lwd=2)
+    par(mfrow=c(1,1),mar=c(5.5,5.5,2,2)+0.1)
+    plot(density(mcmc[[1]]),xlim=c(xmin,xmax),ylim=c(0,ymax),xlab="Absolute Risk",ylab="Density",main="",col=cols[1],lty=1,lwd=2,cex.axis=2,cex.lab=2)
     for(i in 2:ntrt){
       lines(density(mcmc[[i]]),col=cols[i],lty=i,lwd=2)
     }
-    legend("topright",legend=trtname,col=cols,lty=1:ntrt)
+    legend("topright",legend=trtname,col=cols,lty=1:ntrt,lwd=2,cex=1.5)
     dev.off()
   }
+  class(out)<-"nma.ab"
   return(out)
   options(warn=0)
 }
